<?php
/**
 * Login Form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/form-login.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.6.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

$show_reg_form = ( 'yes' === get_option( 'woocommerce_enable_myaccount_registration' ) ) ? true : false;

?>


<!-- begin grid-x -->
<div class="grid-x login-cells">
	
	<!-- begin login-content -->
	<div id="customer_login" class="login-content">

		<?php do_action( 'woocommerce_before_customer_login_form' ); ?>

		<!-- begin login-content-inner -->
		<div class="login-content-inner">

			
			<div id="bb-login-wrap" class="inline slide-up fade-in">
				<div class="title-wrapper">
					<?php barberry_breadcrumbs(); ?>
					<div class="page-title-wrapper">
						<h1 class="page-title"><?php esc_html_e( 'Log in', 'woocommerce' ); ?></h1>
					</div>					
				</div>

				<form class="woocommerce-form woocommerce-form-login login" method="post">
					<?php do_action( 'woocommerce_login_form_start' ); ?>

					<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
						<label for="username"><?php esc_html_e( 'Username or email address', 'woocommerce' ); ?>&nbsp;<span class="required">*</span></label>
						<input type="text" class="woocommerce-Input woocommerce-Input--text input-text" name="username" id="username" autocomplete="username" value="<?php echo ( ! empty( $_POST['username'] ) ) ? esc_attr( wp_unslash( $_POST['username'] ) ) : ''; ?>" /><?php // @codingStandardsIgnoreLine ?>
					</p>
					<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
						<label for="password"><?php esc_html_e( 'Password', 'woocommerce' ); ?>&nbsp;<span class="required">*</span></label>
						<input class="woocommerce-Input woocommerce-Input--text input-text" type="password" name="password" id="password" autocomplete="current-password" />
					</p>

					<?php do_action( 'woocommerce_login_form' ); ?>

	                <p class="form-row form-group login-form-footer">
						<label class="woocommerce-form__label woocommerce-form__label-for-checkbox woocommerce-form-login__rememberme">
							<input class="woocommerce-form__input woocommerce-form__input-checkbox" name="rememberme" type="checkbox" id="rememberme" value="forever" /> <span><?php esc_html_e( 'Remember me', 'woocommerce' ); ?></span>
						</label>
	                    
	                    <span class="woocommerce-LostPassword lost_password">
	                        <a href="<?php echo esc_url( wp_lostpassword_url() ); ?>"><?php esc_html_e( 'Lost your password?', 'woocommerce' ); ?></a>
	                    </span>
	                </p>
	                
	                <p class="form-actions">
	                    <?php wp_nonce_field( 'woocommerce-login', 'woocommerce-login-nonce' ); ?> 
	                                    
	                    <button type="submit" class="woocommerce-Button button" name="login" value="<?php esc_attr_e( 'Log in', 'woocommerce' ); ?>"><?php esc_html_e( 'Log in', 'woocommerce' ); ?></button>
	                    
	                    <?php if ( $show_reg_form ) : ?>
	                    <div class="bb-login-form-divider"><span><?php esc_html_e( 'Or', 'barberry' ); ?></span></div>
	                    <a href="#" id="bb-show-register-button" class="button btn--border"><?php esc_html_e( 'Create an Account', 'barberry' ); ?></a>
	                    <?php endif; ?>
	                </p>

					<?php do_action( 'woocommerce_login_form_end' ); ?>
				</form>
			</div>

			<?php if ( $show_reg_form ) : ?>
				<div id="bb-register-wrap">
					<div class="title-wrapper">
						<?php barberry_breadcrumbs(); ?>
						<div class="page-title-wrapper">
							<h1 class="page-title"><?php esc_html_e( 'Register', 'woocommerce' ); ?></h1>
						</div>					
					</div>

					<form method="post" class="woocommerce-form woocommerce-form-register register" <?php do_action( 'woocommerce_register_form_tag' ); ?> >
						<?php do_action( 'woocommerce_register_form_start' ); ?>
						<?php if ( 'no' === get_option( 'woocommerce_registration_generate_username' ) ) : ?>

						    <p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
								<label for="reg_username"><?php esc_html_e( 'Username', 'woocommerce' ); ?>&nbsp;<span class="required">*</span></label>
								<input type="text" class="woocommerce-Input woocommerce-Input--text input-text" name="username" id="reg_username" autocomplete="username" value="<?php echo ( ! empty( $_POST['username'] ) ) ? esc_attr( wp_unslash( $_POST['username'] ) ) : ''; ?>" /><?php // @codingStandardsIgnoreLine ?>
							</p>

						<?php endif; ?>

						<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
							<label for="reg_email"><?php esc_html_e( 'Email address', 'woocommerce' ); ?>&nbsp;<span class="required">*</span></label>
							<input type="email" class="woocommerce-Input woocommerce-Input--text input-text" name="email" id="reg_email" autocomplete="email" value="<?php echo ( ! empty( $_POST['email'] ) ) ? esc_attr( wp_unslash( $_POST['email'] ) ) : ''; ?>" /><?php // @codingStandardsIgnoreLine ?>
						</p>

						<?php if ( 'no' === get_option( 'woocommerce_registration_generate_password' ) ) : ?>

					    <p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
							<label for="reg_password"><?php esc_html_e( 'Password', 'woocommerce' ); ?>&nbsp;<span class="required">*</span></label>
							<input type="password" class="woocommerce-Input woocommerce-Input--text input-text" name="password" id="reg_password" autocomplete="new-password" />
						</p>
						<?php else : ?>
						<div class="woocommerce-password-text"><p><?php esc_html_e( 'A password will be sent to your email address.', 'woocommerce' ); ?></p></div>

						<?php endif; ?>

						<?php do_action( 'woocommerce_register_form' ); ?>

						<p class="form-actions">
						    <?php wp_nonce_field( 'woocommerce-register', 'woocommerce-register-nonce' ); ?>
						    <button type="submit" class="woocommerce-Button button" name="register" value="<?php esc_attr_e( 'Register', 'woocommerce' ); ?>"><?php esc_html_e( 'Register', 'woocommerce' ); ?></button>
						    
						    <?php if ( $show_reg_form ) : ?>
						    <div class="bb-login-form-divider"><span><?php esc_html_e( 'Or', 'barberry' ); ?></span></div>
						    
						    <a href="#" id="bb-show-login-button" class="button btn--border"><?php esc_html_e( 'Log in', 'woocommerce' ); ?></a>
						    <?php endif; ?>
						</p>

						<?php do_action( 'woocommerce_register_form_end' ); ?>						
					</form>					
				</div>
			<?php endif; ?>
			<?php do_action( 'woocommerce_after_customer_login_form' ); ?>	

		</div>
		<!-- end login-content-inner -->
		
	</div>
	<!-- end login-content -->

</div>
<!-- end grid-x -->